@@ -6,4 +6,6 @@ from .ensemble_boxes_nmw import non_maximum_weighted
 from .ensemble_boxes_nms import nms_method
 from .ensemble_boxes_nms import nms
 from .ensemble_boxes_nms import soft_nms
-from .ensemble_boxes_wbf_3d import weighted_boxes_fusion_3d
\ No newline at end of file
+from .ensemble_boxes_wbf_3d import weighted_boxes_fusion_3d
+from .ensemble_boxes_wbf_1d import weighted_boxes_fusion_1d
+from .ensemble_boxes_wbf_experimental import weighted_boxes_fusion_experimental
\ No newline at end of file
